/// <reference types="node" />
import { IGetToken, IToken } from "token-types";
import { ITokenizer } from "./";
import { Promise } from "bluebird";
export declare abstract class AbstractTokenizer implements ITokenizer {
    fileSize?: number;
    position: number;
    private numBuffer;
    /**
     * Read buffer from tokenizer
     * @param buffer
     * @param offset is the offset in the buffer to start writing at; if not provided, start at 0
     * @param length is an integer specifying the number of bytes to read
     * @param position is an integer specifying where to begin reading from in the file. If position is null, data will be read from the current file position.
     * @returns {Promise<TResult|number>}
     */
    abstract readBuffer(buffer: Buffer | Uint8Array, offset?: number, length?: number, position?: number): Promise<number>;
    /**
     * Peek (read ahead) buffer from tokenizer
     * @param buffer
     * @param offset is the offset in the buffer to start writing at; if not provided, start at 0
     * @param length is an integer specifying the number of bytes to read
     * @param position is an integer specifying where to begin reading from in the file. If position is null, data will be read from the current file position.
     * @returns {Promise<TResult|number>}
     */
    abstract peekBuffer(buffer: Buffer | Uint8Array, offset?: number, length?: number, position?: number): Promise<number>;
    readToken<T>(token: IGetToken<T>, position?: number | null): Promise<T>;
    peekToken<T>(token: IGetToken<T>, position?: number): Promise<T>;
    readNumber(token: IToken<number>): Promise<number>;
    peekNumber(token: IToken<number>): Promise<number>;
    /**
     * @return actual number of bytes ignored
     */
    abstract ignore(length: number): Promise<number>;
}
