/// <reference types="node" />
import { AbstractTokenizer } from "./AbstractTokenizer";
import { Promise } from "bluebird";
export declare class FileTokenizer extends AbstractTokenizer {
    private fd;
    fileSize?: number;
    private _close;
    constructor(fd: number, fileSize?: number);
    /**
     * Read buffer from file
     * @param buffer
     * @param offset is the offset in the buffer to start writing at; if not provided, start at 0
     * @param length is an integer specifying the number of bytes to read, of not provided the buffer length will be used
     * @param position is an integer specifying where to begin reading from in the file. If position is null, data will be read from the current file position.
     * @returns Promise number of bytes read
     */
    readBuffer(buffer: Buffer, offset?: number, length?: number, position?: number): Promise<number>;
    /**
     * Peek buffer from file
     * @param buffer
     * @param offset is the offset in the buffer to start writing at; if not provided, start at 0
     * @param length is an int
     * eger specifying the number of bytes to read, of not provided the buffer length will be used
     * @param position is an integer specifying where to begin reading from in the file. If position is null, data will be read from the current file position.
     * @returns Promise number of bytes read
     */
    peekBuffer(buffer: Buffer, offset?: number, length?: number, position?: number): Promise<number>;
    /**
     * @param length Number of bytes to ignore
     */
    ignore(length: number): Promise<number>;
    close(): Promise<void>;
    private _read;
}
